#[repr(u32)]pub enum FirmwareVersionType {
FIRMWARE_VERSION_TYPE_DEV = 0,
FIRMWARE_VERSION_TYPE_ALPHA = 64,
FIRMWARE_VERSION_TYPE_BETA = 128,
FIRMWARE_VERSION_TYPE_RC = 192,
FIRMWARE_VERSION_TYPE_OFFICIAL = 255,
}Available on crate feature
dialect-standard only.Expand description
These values define the type of firmware release. These values indicate the first version or release of this type. For example the first alpha release would be 64, the second would be 65.
Variants
FIRMWARE_VERSION_TYPE_DEV = 0
development release
FIRMWARE_VERSION_TYPE_ALPHA = 64
alpha release
FIRMWARE_VERSION_TYPE_BETA = 128
beta release
FIRMWARE_VERSION_TYPE_RC = 192
release candidate
FIRMWARE_VERSION_TYPE_OFFICIAL = 255
official stable release
Implementations