pub struct MavModeFlag(/* private fields */);dialect-standard only.Expand description
These flags encode the MAV mode, see MAV_MODE enum for useful combinations.
Implementations
Sourceimpl MavModeFlag
impl MavModeFlag
Sourcepub const MAV_MODE_FLAG_SAFETY_ARMED: Self
pub const MAV_MODE_FLAG_SAFETY_ARMED: Self
0b10000000 MAV safety set to armed. Motors are enabled / running / can start. Ready to fly. Additional note: this flag is to be ignore when sent in the command MAV_CMD_DO_SET_MODE and MAV_CMD_COMPONENT_ARM_DISARM shall be used instead. The flag can still be used to report the armed state.
Sourcepub const MAV_MODE_FLAG_MANUAL_INPUT_ENABLED: Self
pub const MAV_MODE_FLAG_MANUAL_INPUT_ENABLED: Self
0b01000000 remote control input is enabled.
Sourcepub const MAV_MODE_FLAG_HIL_ENABLED: Self
pub const MAV_MODE_FLAG_HIL_ENABLED: Self
0b00100000 hardware in the loop simulation. All motors / actuators are blocked, but internal software is full operational.
Sourcepub const MAV_MODE_FLAG_STABILIZE_ENABLED: Self
pub const MAV_MODE_FLAG_STABILIZE_ENABLED: Self
0b00010000 system stabilizes electronically its attitude (and optionally position). It needs however further control inputs to move around.
Sourcepub const MAV_MODE_FLAG_GUIDED_ENABLED: Self
pub const MAV_MODE_FLAG_GUIDED_ENABLED: Self
0b00001000 guided mode enabled, system flies waypoints / mission items.
Sourcepub const MAV_MODE_FLAG_AUTO_ENABLED: Self
pub const MAV_MODE_FLAG_AUTO_ENABLED: Self
0b00000100 autonomous mode enabled, system finds its own goal positions. Guided flag can be set or not, depends on the actual implementation.
Sourcepub const MAV_MODE_FLAG_TEST_ENABLED: Self
pub const MAV_MODE_FLAG_TEST_ENABLED: Self
0b00000010 system has a test mode enabled. This flag is intended for temporary system tests and should not be used for stable implementations.
Sourcepub const MAV_MODE_FLAG_CUSTOM_MODE_ENABLED: Self
pub const MAV_MODE_FLAG_CUSTOM_MODE_ENABLED: Self
0b00000001 system-specific custom mode is enabled. When using this flag to enable a custom mode all other flags should be ignored.
Sourceimpl MavModeFlag
impl MavModeFlag
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MavModeFlag
impl MavModeFlag
Sourcepub const fn iter(&self) -> Iter<MavModeFlag>
pub const fn iter(&self) -> Iter<MavModeFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MavModeFlag>
pub const fn iter_names(&self) -> IterNames<MavModeFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl MavModeFlag
impl MavModeFlag