pub struct MavModeFlagDecodePosition(/* private fields */);dialect-standard only.Expand description
These values encode the bit positions of the decode position. These values can be used to read the value of a flag bit by combining the base_mode variable with AND with the flag position value. The result will be either 0 or 1, depending on if the flag is set or not.
Implementations
Sourceimpl MavModeFlagDecodePosition
impl MavModeFlagDecodePosition
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_SAFETY: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_SAFETY: Self
First bit: 10000000
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_MANUAL: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_MANUAL: Self
Second bit: 01000000
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_HIL: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_HIL: Self
Third bit: 00100000
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_STABILIZE: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_STABILIZE: Self
Fourth bit: 00010000
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_GUIDED: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_GUIDED: Self
Fifth bit: 00001000
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_AUTO: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_AUTO: Self
Sixth bit: 00000100
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_TEST: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_TEST: Self
Seventh bit: 00000010
Sourcepub const MAV_MODE_FLAG_DECODE_POSITION_CUSTOM_MODE: Self
pub const MAV_MODE_FLAG_DECODE_POSITION_CUSTOM_MODE: Self
Eighth bit: 00000001
Sourceimpl MavModeFlagDecodePosition
impl MavModeFlagDecodePosition
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MavModeFlagDecodePosition
impl MavModeFlagDecodePosition
Sourcepub const fn iter(&self) -> Iter<MavModeFlagDecodePosition>
pub const fn iter(&self) -> Iter<MavModeFlagDecodePosition>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MavModeFlagDecodePosition>
pub const fn iter_names(&self) -> IterNames<MavModeFlagDecodePosition>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.