#[repr(u32)]pub enum MavMessage {
AUTOPILOT_VERSION(AUTOPILOT_VERSION_DATA),
GLOBAL_POSITION_INT(GLOBAL_POSITION_INT_DATA),
HEARTBEAT(HEARTBEAT_DATA),
}Available on crate feature
dialect-standard only.Variants
AUTOPILOT_VERSION(AUTOPILOT_VERSION_DATA)
Version and capability of autopilot software. This should be emitted in response to a request with MAV_CMD_REQUEST_MESSAGE.
ID: 148
GLOBAL_POSITION_INT(GLOBAL_POSITION_INT_DATA)
The filtered global position (e.g. fused GPS and accelerometers). The position is in GPS-frame (right-handed, Z-up). It is designed as scaled integer message since the resolution of float is not sufficient.
ID: 33
HEARTBEAT(HEARTBEAT_DATA)
The heartbeat message shows that a system or component is present and responding. The type and autopilot fields (along with the message component id), allow the receiving system to treat further messages from this system appropriately (e.g. by laying out the user interface based on the autopilot). This microservice is documented at https://mavlink.io/en/services/heartbeat.html.
ID: 0
Implementations
Sourceimpl MavMessage
impl MavMessage